[![Build Status](https://app.travis-ci.com/cs107-errajexi/cs107-FinalProject.svg?token=MV6ZCvzJMZTkyEnN1o6m&branch=main)](https://app.travis-ci.com/cs107-errajexi/cs107-FinalProject)
[![codecov](https://codecov.io/gh/cs107-errajexi/cs107-FinalProject/branch/main/graph/badge.svg?token=DGJBAM78NF)](https://codecov.io/gh/cs107-errajexi/cs107-FinalProject)
[![docs](https://img.shields.io/static/v1.svg?label=docs&message=0.0.1&color=blue)](https://cs107-errajexi.github.io/cs107-FinalProject/)

# cs107-FinalProject

AC207 Fall 21

Group number 18

Repo that will be graded.


## Team:
1. Raphael Pellegrin: 	raphaelpellegrin@g.harvard.edu
2. Jean Guillaume Brasier: jbrasier@g.harvard.edu
3. Eryk Pecyna: erykpecyna@college.harvard.edu
4. Xiyu Yang: xiyuyang@fas.harvard.edu
